@@ -39,5 +39,8 @@ class SparkCommandSubmitOperator(BaseOperator):
         payload = {"type": self.code_type, "code": self.code, "result_type": self.result_type, "result_url": self.result_url}
         json_payload = json.dumps(payload)
         headers = {"Content-Type": "application/json"}
+        logger.info(f'Payload: {json_payload}')
         response = requests.post(self.endpoint_url, data=json_payload, headers=headers)
+        logger.info('After POST')
+        logger.info(f'Response: {response.text}')
         return response.text
